Package: mlrMBO
Title: Bayesian Optimization and Model-Based Optimization of Expensive
        Black-Box Functions
Version: 1.1.6
Authors@R: c(
    person("Bernd", "Bischl", , "bernd_bischl@gmx.net", role = "aut",
           comment = c(ORCID = "0000-0001-6002-6980")),
    person("Jakob", "Richter", , "code@jakob-r.de", role = "aut",
           comment = c(ORCID = "0000-0003-4481-5554")),
    person("Jakob", "Bossek", , "j.bossek@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-4121-4668")),
    person("Daniel", "Horn", , "daniel.horn@tu-dortmund.de", role = "aut"),
    person("Michel", "Lang", , "michellang@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0001-9754-0393")),
    person("Janek", "Thomas", , "janek.thomas@stat.uni-muenchen.de", role = "aut",
           comment = c(ORCID = "0000-0003-4511-6245")),
    person("Martin", "Binder", , "mlr.developer@mb706.com", role = "cre")
  )
Description: Flexible and comprehensive R toolbox for model-based
    optimization ('MBO'), also known as Bayesian optimization. It
    implements the Efficient Global Optimization Algorithm and is designed
    for both single- and multi- objective optimization with mixed
    continuous, categorical and conditional parameters. The machine
    learning toolbox 'mlr' provide dozens of regression learners to model
    the performance of the target algorithm with respect to the parameter
    settings. It provides many different infill criteria to guide the
    search process. Additional features include multi-point batch
    proposal, parallel execution as well as visualization and
    sophisticated logging mechanisms, which is especially useful for
    teaching and understanding of algorithm behavior. 'mlrMBO' is
    implemented in a modular fashion, such that single components can be
    easily replaced or adapted by the user for specific use cases.
License: BSD_2_clause + file LICENSE
URL: https://github.com/mlr-org/mlrMBO
BugReports: https://github.com/mlr-org/mlrMBO/issues
Depends: mlr (>= 2.10), ParamHelpers (>= 1.10), smoof (>= 1.5.1)
Imports: backports (>= 1.1.0), BBmisc (>= 1.11), checkmate (>= 1.8.2),
        data.table, lhs, parallelMap (>= 1.3)
Suggests: akima, cmaesr (>= 1.0.3), covr, DiceKriging, earth, emoa,
        GGally, ggplot2, gridExtra, interp, kernlab, kknn, knitr, mco,
        nnet, party, randomForest, reshape2, rgenoud, rmarkdown, rpart,
        testthat
VignetteBuilder: knitr
ByteCompile: yes
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-02-28 11:42:09 UTC; user
Author: Bernd Bischl [aut] (ORCID: <https://orcid.org/0000-0001-6002-6980>),
  Jakob Richter [aut] (ORCID: <https://orcid.org/0000-0003-4481-5554>),
  Jakob Bossek [aut] (ORCID: <https://orcid.org/0000-0002-4121-4668>),
  Daniel Horn [aut],
  Michel Lang [aut] (ORCID: <https://orcid.org/0000-0001-9754-0393>),
  Janek Thomas [aut] (ORCID: <https://orcid.org/0000-0003-4511-6245>),
  Martin Binder [cre]
Maintainer: Martin Binder <mlr.developer@mb706.com>
Repository: CRAN
Date/Publication: 2026-03-01 06:10:15 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 07:22:19 UTC; unix
Archs: mlrMBO.so.dSYM
