# Generated by roxygen2: do not edit by hand

S3method(initCrit,InfillCritAdaCB)
S3method(initCrit,InfillCritCB)
S3method(initCrit,default)
S3method(plot,MBOMultiObjResult)
S3method(plot,MBOSingleObjResult)
S3method(plot,OptState)
S3method(print,MBOControl)
S3method(print,MBOExampleRun)
S3method(print,MBOExampleRunMultiObj)
S3method(print,MBOInfillCrit)
S3method(print,MBOMultiObjResult)
S3method(print,MBOResult)
S3method(print,OptState)
S3method(renderExampleRunPlot,MBOExampleRun)
S3method(renderExampleRunPlot,MBOExampleRunMultiObj)
export(crit.aei)
export(crit.cb)
export(crit.cb1)
export(crit.cb2)
export(crit.dib1)
export(crit.ei)
export(crit.eqi)
export(crit.mr)
export(crit.se)
export(exampleRun)
export(exampleRunMultiObj)
export(finalizeSMBO)
export(getGlobalOpt)
export(getMBOInfillCritComponents)
export(getMBOInfillCritId)
export(getMBOInfillCritName)
export(getMBOInfillCritParam)
export(getMBOInfillCritParams)
export(getSupportedInfillOptFunctions)
export(getSupportedMultipointInfillOptFunctions)
export(hasRequiresInfillCritStandardError)
export(initCrit)
export(initSMBO)
export(makeMBOControl)
export(makeMBOInfillCrit)
export(makeMBOInfillCritAEI)
export(makeMBOInfillCritAdaCB)
export(makeMBOInfillCritCB)
export(makeMBOInfillCritDIB)
export(makeMBOInfillCritEI)
export(makeMBOInfillCritEQI)
export(makeMBOInfillCritMeanResponse)
export(makeMBOInfillCritStandardError)
export(makeMBOLearner)
export(makeMBOTrafoFunction)
export(mbo)
export(mboContinue)
export(mboFinalize)
export(plotExampleRun)
export(proposePoints)
export(renderExampleRunPlot)
export(setMBOControlInfill)
export(setMBOControlMultiObj)
export(setMBOControlMultiPoint)
export(setMBOControlTermination)
export(trafoLog)
export(trafoSqrt)
export(updateSMBO)
import(BBmisc)
import(ParamHelpers)
import(checkmate)
import(data.table)
import(grDevices)
import(mlr)
import(parallelMap)
import(smoof)
import(stats)
import(utils)
importFrom(lhs,randomLHS)
useDynLib(mlrMBO,c_eps_indicator)
useDynLib(mlrMBO,c_sms_indicator)
